/*****************************************************************************************
 ** File     : Debug.cpp
 ** Date     : 03/09/2002
 ** Author   : Osama Dengler <osama@denglernet.de>
 ** Abstract : Debugging support for the Password filter dll
 **
 ** Copyright (C) Osama Dengler 2002
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *****************************************************************************************/
#include "stdafx.h"
#include "PasswordFilter.h"

#ifdef _DEBUG
//#define DEBUG_TIMESTAMPS

FILE *logfile=NULL;				// make Logfile globally available

/*************************************************************************************************
 ** Function  : DEBUGMSG
 ** Purpose   : Print a debugging message to the logfile
 ** Author    : O. Dengler
 ** History   : 03/09/2002 : 1st
 ************************************************************************************************/
void DEBUGMSG(char *format_str, ... )
{
	va_list ap;  

#ifdef DEBUG_TIMESTAMPS
	SYSTEMTIME tm;

	GetLocalTime(&tm);
	fprintf(logfile,"%02u/%02u/%04u - %02u:%02u:%02u:%03u : ",
		tm.wMonth,
		tm.wDay,
		tm.wYear,
		tm.wHour,
		tm.wMinute,
		tm.wSecond,
		tm.wMilliseconds);
#endif DEBUG_TIMESTAMPS

    va_start( ap, format_str );
	vfprintf( logfile, format_str, ap );
	fflush(logfile);
}

/*************************************************************************************************
 ** Function  : DEBUG_DUMP_MEMORY
 ** Purpose   : Dump the contents of a memory area to the logfile as hex and ASCII data.
 ** Author    : O. Dengler
 ** History   : 03/09/2002 : 1st
 ************************************************************************************************/
void DEBUG_DUMP_MEMORY(PVOID Address, UINT count)
{
#define BYTES_PER_ROW 8

	int rows= count / BYTES_PER_ROW;
	int rest= count % BYTES_PER_ROW;
	int n;

	PBYTE pBuf= (PBYTE)Address;

	try
	{
		for(n=0; n<rows; n++)
		{
			DEBUGMSG("%08x : %02x %02x %02x %02x  %02x %02x %02x %02x",
				pBuf+n*BYTES_PER_ROW,
				pBuf[n*BYTES_PER_ROW  ], pBuf[n*BYTES_PER_ROW+1],
				pBuf[n*BYTES_PER_ROW+2], pBuf[n*BYTES_PER_ROW+3],
				pBuf[n*BYTES_PER_ROW+4], pBuf[n*BYTES_PER_ROW+5],
				pBuf[n*BYTES_PER_ROW+6], pBuf[n*BYTES_PER_ROW+7]);

			DEBUGMSG("  %c%c%c%c %c%c%c%c\n",
				pBuf[n*BYTES_PER_ROW  ], pBuf[n*BYTES_PER_ROW+1],
				pBuf[n*BYTES_PER_ROW+2], pBuf[n*BYTES_PER_ROW+3],
				pBuf[n*BYTES_PER_ROW+4], pBuf[n*BYTES_PER_ROW+5],
				pBuf[n*BYTES_PER_ROW+6], pBuf[n*BYTES_PER_ROW+7]);
		}

		if(rest != 0)
		{
			DEBUGMSG("%08x : ", pBuf+rows*BYTES_PER_ROW);

			for(n=0; n<rest; n++) DEBUGMSG("%02x ", pBuf[rows+n]);
			for(n=0; n<rest; n++) DEBUGMSG("%c", pBuf[rows+n]);

			DEBUGMSG("\n");
		}
	}
	catch(...)
	{
		DEBUGMSG("$$$ LdapLsaAp Exception in DEBUG_DUMP_MEMORY $$$\n");
	}

#undef BYTES_PER_ROW

}

/******************************************************************************************
 ** Name       : DumpSysDateTime
 ** Purpose    : Dump the System time in readable form
 ** Parameters : pTime      - System Time structure
 **              TimeString - Destination buffer
 ** Description: Returns the destination buffer
 ******************************************************************************************/
TCHAR* DumpSysDateTime(PSYSTEMTIME pTime, TCHAR *TimeString) {
	TCHAR *Days[]={TEXT("Mon"),TEXT("Tue"),TEXT("Wed"),TEXT("Thu"),TEXT("Fri"),TEXT("Sat"),TEXT("Sun")};

	if(TimeString != NULL)
		_stprintf(TimeString,L"%s, %02u.%02u.%04u - %02u:%02u:%02u:%u",
						Days[pTime->wDayOfWeek],
						pTime->wDay,
						pTime->wMonth,
						pTime->wYear,
						pTime->wHour,
						pTime->wMinute,
						pTime->wSecond,
						pTime->wMilliseconds);
	
	return(TimeString);
}

/******************************************************************************************
 ** Name       : DumpSysDateTimeShort
 ** Purpose    : Dump the System time in a short readable form
 ** Parameters : pTime      - System Time structure
 **              TimeString - Destination buffer
 ** Description: Returns the destination buffer
 ******************************************************************************************/
TCHAR* DumpSysDateTimeShort(PSYSTEMTIME pTime, TCHAR *TimeString) {

	if(TimeString != NULL)
		_stprintf(TimeString,L"%02u.%02u.%04u_%02u.%02u.%02u.%u",
						pTime->wDay,
						pTime->wMonth,
						pTime->wYear,
						pTime->wHour,
						pTime->wMinute,
						pTime->wSecond,
						pTime->wMilliseconds);
	
	return(TimeString);
}

#else

void DEBUGMSG(char *format_str, ... ) {}
void DEBUG_DUMP_MEMORY(PVOID Address, UINT count) {}

#endif _DEBUG
